==> hm-modules-0.9.4-sources.jar: org/hortonmachine/modules/VectorSimplifier.java <==
/*
 * This file is part of HortonMachine (http://www.hortonmachine.org)
 * (C) HydroloGIS - www.hydrologis.com 
 * 
 * The HortonMachine is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.hortonmachine.modules;

import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_AUTHORCONTACTS;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_AUTHORNAMES;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_DESCRIPTION;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_IN_VECTOR_DESCRIPTION;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_KEYWORDS;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_LABEL;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_LICENSE;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_NAME;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_OUT_VECTOR_DESCRIPTION;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_P_TOLERANCE_DESCRIPTION;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_P_TYPE_DESCRIPTION;
import static org.hortonmachine.gears.i18n.GearsMessages.OMSVECTORSIMPLIFIER_STATUS;

import org.hortonmachine.gears.libs.modules.HMConstants;
import org.hortonmachine.gears.libs.modules.HMModel;
import org.hortonmachine.gears.modules.v.vectorsimplifier.OmsVectorSimplifier;

import oms3.annotations.Author;
import oms3.annotations.Description;
import oms3.annotations.Execute;
import oms3.annotations.In;
import oms3.annotations.Keywords;
import oms3.annotations.Label;
import oms3.annotations.License;
import oms3.annotations.Name;
import oms3.annotations.Status;
import oms3.annotations.UI;

@Description(OMSVECTORSIMPLIFIER_DESCRIPTION)
@Author(name = OMSVECTORSIMPLIFIER_AUTHORNAMES, contact = OMSVECTORSIMPLIFIER_AUTHORCONTACTS)
@Keywords(OMSVECTORSIMPLIFIER_KEYWORDS)
@Label(OMSVECTORSIMPLIFIER_LABEL)
@Name("_" + OMSVECTORSIMPLIFIER_NAME)
@Status(OMSVECTORSIMPLIFIER_STATUS)
@License(OMSVECTORSIMPLIFIER_LICENSE)
public class VectorSimplifier extends HMModel {

    @Description(OMSVECTORSIMPLIFIER_IN_VECTOR_DESCRIPTION)
    @UI(HMConstants.FILEIN_UI_HINT_VECTOR)
    @In
    public String inVector;

    @Description(OMSVECTORSIMPLIFIER_P_TYPE_DESCRIPTION)
    @In
    public int pType = 0;

    @Description(OMSVECTORSIMPLIFIER_P_TOLERANCE_DESCRIPTION)
    @In
    public double pTolerance = 0.2;

    @Description(OMSVECTORSIMPLIFIER_OUT_VECTOR_DESCRIPTION)
    @UI(HMConstants.FILEOUT_UI_HINT)
    @In
    public String outVector;

    @Execute
    public void process() throws Exception {
        OmsVectorSimplifier vectorsimplifier = new OmsVectorSimplifier();
        vectorsimplifier.inVector = getVector(inVector);
        vectorsimplifier.pType = pType;
        vectorsimplifier.pTolerance = pTolerance;
        vectorsimplifier.pm = pm;
        vectorsimplifier.doProcess = doProcess;
        vectorsimplifier.doReset = doReset;
        vectorsimplifier.process();
        dumpVector(vectorsimplifier.outVector, outVector);
    }
}

==> hm-modules-0.9.7-sources.jar: org/hortonmachine/modules/VectorSimplifier.java <==
/*
 * This file is part of HortonMachine (http://www.hortonmachine.org)
 * (C) HydroloGIS - www.hydrologis.com 
 * 
 * The HortonMachine is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.hortonmachine.modules;

import static org.hortonmachine.gears.libs.modules.Variables.DOUGLAS_PEUCKER;
import static org.hortonmachine.gears.libs.modules.Variables.PRECISION_REDUCER;
import static org.hortonmachine.gears.libs.modules.Variables.TOPOLOGYPRESERVINGSIMPLIFIER;
import static org.hortonmachine.gears.modules.v.vectorsimplifier.OmsVectorSimplifier.*;

import org.hortonmachine.gears.libs.modules.HMConstants;
import org.hortonmachine.gears.libs.modules.HMModel;
import org.hortonmachine.gears.modules.v.vectorsimplifier.OmsVectorSimplifier;

import oms3.annotations.Author;
import oms3.annotations.Description;
import oms3.annotations.Execute;
import oms3.annotations.In;
import oms3.annotations.Keywords;
import oms3.annotations.Label;
import oms3.annotations.License;
import oms3.annotations.Name;
import oms3.annotations.Status;
import oms3.annotations.UI;

@Description(OMSVECTORSIMPLIFIER_DESCRIPTION)
@Author(name = OMSVECTORSIMPLIFIER_AUTHORNAMES, contact = OMSVECTORSIMPLIFIER_AUTHORCONTACTS)
@Keywords(OMSVECTORSIMPLIFIER_KEYWORDS)
@Label(OMSVECTORSIMPLIFIER_LABEL)
@Name("_" + OMSVECTORSIMPLIFIER_NAME)
@Status(OMSVECTORSIMPLIFIER_STATUS)
@License(OMSVECTORSIMPLIFIER_LICENSE)
public class VectorSimplifier extends HMModel {

    @Description(OMSVECTORSIMPLIFIER_IN_VECTOR_DESCRIPTION)
    @UI(HMConstants.FILEIN_UI_HINT_VECTOR)
    @In
    public String inVector;

    @Description(OMSVECTORSIMPLIFIER_P_TYPE_DESCRIPTION)
    @UI("combo:" + TOPOLOGYPRESERVINGSIMPLIFIER + "," + DOUGLAS_PEUCKER + "," + PRECISION_REDUCER)
    @In
    public String pType = TOPOLOGYPRESERVINGSIMPLIFIER;

    @Description(OMSVECTORSIMPLIFIER_P_TOLERANCE_DESCRIPTION)
    @In
    public double pTolerance = 0.2;

    @Description(OMSVECTORSIMPLIFIER_P_SCALE_DESCRIPTION)
    @In
    public Double pScale = 1000.0;
    
    @Description(OMSVECTORSIMPLIFIER_OUT_VECTOR_DESCRIPTION)
    @UI(HMConstants.FILEOUT_UI_HINT)
    @In
    public String outVector;

    @Execute
    public void process() throws Exception {
        OmsVectorSimplifier vectorsimplifier = new OmsVectorSimplifier();
        vectorsimplifier.inVector = getVector(inVector);
        vectorsimplifier.pType = pType;
        vectorsimplifier.pScale = pScale;
        vectorsimplifier.pTolerance = pTolerance;
        vectorsimplifier.pm = pm;
        vectorsimplifier.doProcess = doProcess;
        vectorsimplifier.doReset = doReset;
        vectorsimplifier.process();
        dumpVector(vectorsimplifier.outVector, outVector);
    }
}
